from distutils.core import setup

setup(
    name="spartaORM",
    packages=["spartaORM"],
    version="0.1.0",
    license="MIT",
    description="Simple ORM for Sparta",
    author="Arun Kumar",
    author_email="arun.kumar@swimming.org.au",
    url="https://gitlab.com/arun-ak/sparta-database-orm",
    download_url="https://gitlab.com/arun-ak/sparta-database-orm/-/archive/0.1.0/sparta-database-orm-0.1.0.tar.gz",
    install_requires=["alembic", "sqlalchemy", "psycopg2"],
    classifiers=["Topic :: Software Development :: Build Tools",],
)



from spartaORM.controller.athlete import Athlete
from spartaORM.controller.race import Race
from spartaORM.controller.pacing import Pacing
from spartaORM.controller.averages import Averages
from spartaORM.controller.official_results import OfficialResults
from spartaORM.controller.segment_metrics import SegmentMetrics
from spartaORM.controller.summary_metrics import SummaryMetrics
